@@ -3,7 +3,8 @@ import asyncio
 from pathlib import Path
 from datetime import datetime, timezone
 from basic_logtools.filelog import LogFile
-
+import re
+from networktools.path import home_path
 
 
 class GeneralData:
@@ -17,7 +18,8 @@ class GeneralData:
             self.address = (self.host, self.port)
         self.code = kwargs.get('code', 'NONE')
         self.hostname = kwargs.get('hostname', 'atlas')
-        log_path = kwargs.get('log_path','~/data_log')
+        home = re.compile("^~")
+        log_path = home_path(kwargs.get('log_path','~/data_log'))
         log_level = kwargs.get('log_level', 'INFO')
         self.logger = LogFile(self.class_name,
                               self.code,
@@ -117,3 +119,6 @@ class GeneralData:
 
     def stop(self):
         pass
+
+    def close(self):
+        self.logger.close()
